using AutoScan;
using CasaBotApp.TelegramBot;
using Microsoft.Extensions.Logging;

namespace CasaBotApp.Controllers;

public class AutoScanController : IController
{
    private readonly BotHandler _botHandler;
    private readonly AutoScanApp _autoScanApp;
    private readonly ILogger<AutoScanController> _logger;

    public AutoScanController(BotHandler botHandler, AutoScanApp autoScanApp, ILogger<AutoScanController> logger)
    {
        _botHandler = botHandler;
        _autoScanApp = autoScanApp;
        _logger = logger;
    }

    public void Register()
    {
        _autoScanApp.OnScanCompleted = async () =>
        {
            _logger.LogInformation("Scan completed at {At}", DateTime.Now);
            try
            {
                var images = _autoScanApp.GetLastScanPictures();
                if (images.Length == 0)
                {
                    await _botHandler.UpdateText("No images found");
                    return;
                }
                await _botHandler.UpdateText($"Scan completed, found {images.Length} images");
                await _botHandler.UpdatePhotos(images);    
            }catch(Exception ex)
            {
                _logger.LogError(ex, "Error while sending message");
            }
        };
    }
}