using AutoScan.Interfaces;
using CasaBotApp.TelegramBot;
using ControlServer;
using Microsoft.Extensions.Logging;

namespace CasaBotApp.Controllers;

public class ServerController : IController
{
    private readonly IControlServer _controlServer;
    private readonly BotHandler _botHandler;
    private readonly ISnapshoter _snapshoter;
    private readonly ILogger<ServerController> _logger;
    private readonly IShinobiLinkFactory _shinobiLinkFactory;

    public ServerController(IControlServer controlServer, ISnapshoter snapshoter, ILogger<ServerController> logger, IShinobiLinkFactory shinobiLinkFactory, BotHandler botHandler)
    {
        _controlServer = controlServer;
        _snapshoter = snapshoter;
        _logger = logger;
        _shinobiLinkFactory = shinobiLinkFactory;
        _botHandler = botHandler;
    }

    public void Register()
    {
        _controlServer.OnEvent(async sensorEvent =>
        {
            var mediaPath = await _snapshoter.TakeSnapshot();
            if (string.IsNullOrEmpty(mediaPath))
            {
                await _botHandler.AlertText("Unauthorized access detected 🚨🚨🚨, but no media available");
                return;
            }
            if (sensorEvent.Type == EventType.Fired)
            {
                await _botHandler.AlertPhoto(mediaPath,
                    "Unauthorized access detected 🚨 🚨 🚨",
                    [
                        new(OptionType.Url, "Camera Feed", _shinobiLinkFactory.BuildFeedLink()),
                        new(OptionType.Action, "Authorize", $"authorize-{sensorEvent.EventId}", (_, _ ) =>
                        {
                            _logger.LogWarning("Authorizing event {EventId}", sensorEvent.EventId);
                            _controlServer.AuthorizeEvent(sensorEvent.EventId);
                            return Task.FromResult("Entrance authorized");
                        }),
                    ]);
            }

            if (sensorEvent.Type == EventType.DisarmedEntrance)
            {
                await _botHandler.UpdateText("Authorize access");
            }
        });
    }
}